@@ -22,7 +22,7 @@ labels = np.array(data[b'labels'][0:20])
 # labels = np.array(labels[0:50])
 
 
-image_shape = (3, 32, 32)
+image_shape = (3, 64, 64)
 
 image_model_list = [
     ImageModel(network_name="EfficientNetB0",
@@ -35,9 +35,10 @@ image_models = ImageModels(image_model_list=image_model_list)
 diamond_collector = run(images=images,
                         image_shape=image_shape,
                         labels=labels,
-                        get_image_description=True,
-                        is_augment_data=True,
+                        get_image_description=False,
+                        get_object_detection=True,
+                        is_augment_data=False,
                         image_augmentation_info=ImagesAugmentationInfo(aug_prop=0.1),
-                        is_train_model=True, image_models=image_models,
-                        is_post_model_analysis=True,
-                        plot=True)
+                        is_train_model=False, image_models=image_models,
+                        is_post_model_analysis=False,
+                        plot=False)
